# Introduction

Pagic is a static site generator powered by Deno + React.

It is easy to configure, supports rendering `md/tsx` to static HTML page, and has a large number of official or third-party themes and plugins.

## Features

### Easy to configure

Pagic follows the principle of [Convention over configuration](https://en.wikipedia.org/wiki/Convention_over_configuration), to reduce config options as much as possible, through some intuitive design, reduce the user's understanding cost, without losing flexibility.

### Support md and tsx

Pagic not only supports rendering `md/tsx` to static HTML page, but also runs React Hooks in `tsx`. With the programmability of React components, it greatly expands the capabilities of static websites.

It is worth noting that each page generated by Pagic has its own pre-rendered static HTML, providing great loading performance and is SEO-friendly. Yet, once the page is loaded, React takes over the static content and turns it into a full Single-Page Application (SPA). Extra pages are fetched on demand as the user navigates around the site.

### Themes and plugins

Pagic has official themes default/docs/blog. We can use the official theme to easily generate a website, also we can easily create a personalized theme, and even extend a theme-these capabilities are all thanks to Pagic’s intuitive `_layout.tsx` design.

The plugin is one of Pagic's core features. Pagic splits the entire build process into built-in plugins, allowing other plugins to be inserted at any position in the build process, and even completely change Pagic's build process by replacing the built-in plugins, which provides Pagic with unparalleled flexibility.

Pagic refers to the design of Deno and requires users to import third-party themes or plugins through a complete URL.

## Compare to others

As a "static site generator fanatic", I have used most of the popular static site generators. They are all excellent, but Pagic tried some new design concepts. Here are some key differences:

|                       | Pagic | VuePress | Hexo | Jekyll | Hugo |
| --------------------- | ----- | -------- | ---- | ------ | ---- |
| Support `md`          | ✓     | ✓        | ✓    | ✓      | ✓    |
| React/Vue             | ✓     | ✓        |      |        |      |
| SPA                   | ✓     | ✓        |      |        |      |
| Allow `tsx` in config | ✓     |          |      |        |      |
| ...                   |       |          |      |        |      |

Pagic stands on the shoulders of giants and refers to the config options and documents of some other static site generators. Hereby, I would like to express my sincere thanks to these open source projects and communities.
